CREATE TABLE CTUSR.SR_EVENTPROC_LOG
  (
    JOB_ID           NUMBER NOT NULL ENABLE,
    PARENT_JOB_ID    NUMBER DEFAULT -1,
    EVENT_ID         NUMBER,
    STARTED          DATE DEFAULT sysdate,
    COMPLETED        DATE DEFAULT sysdate,
    TASK_ID          NUMBER DEFAULT 0,
    MSG_ID           NUMBER DEFAULT 0,
    CORRELATION_ID   VARCHAR2(400  BYTE),
	GU_ID            NUMBER DEFAULT 1,
    SOURCE           VARCHAR2(4000 BYTE),
    TARGET_ID        NUMBER,
    RETRY            NUMBER,
    RESPONSE         VARCHAR2(4000 BYTE),
    STATUS           NUMBER,
    CONSTRAINT SR_EVENTPROC_LOG PRIMARY KEY (JOB_ID) ENABLE
  )
 ;

CREATE TABLE CTUSR.SR_MESSAGE_LOG
  (
    ENTRY_ID       NUMBER NOT NULL ENABLE,
    MSG_CODE       VARCHAR2(20 BYTE),
    MSG_NATIVECODE VARCHAR2(4000 BYTE),
    MSG_SOURCE     VARCHAR2(4000 BYTE),
    MSG_TYPE       VARCHAR2(10 BYTE) DEFAULT 'INFO' NOT NULL ENABLE,
    MSG_TEXT       VARCHAR2(4000 BYTE) DEFAULT 'NA',
    TIMESTAMP      DATE DEFAULT sysdate,
    USER_ID        VARCHAR2(20 BYTE),
    JOB_ID         NUMBER,
    CONSTRAINT SR_MESSAGE_LOG PRIMARY KEY (ENTRY_ID) ENABLE
  )
;

CREATE TABLE CTUSR.PARAMETER
(
  PARAMETER_ID NUMBER NOT NULL,
  PARAMETER_NAME VARCHAR2(40) NOT NULL,
  PARAMETER_TYPE VARCHAR2(40) NOT NULL,
  PARAMETER_DESCRIPTION VARCHAR2(2000)
, CONSTRAINT PARAMETER_PK PRIMARY KEY
  (
    PARAMETER_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.ENDPOINT_TYPE
(
  ENDPOINTYPE_ID NUMBER NOT NULL,
  ENDPOINTTYPE_NAME VARCHAR2(40) NOT NULL,
  ENDPOINT_DESCRIPTION VARCHAR2(2000)
, CONSTRAINT ENDPOINTTYPE_PK PRIMARY KEY
  (
    ENDPOINTYPE_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.BU_LOCATION
(
  BU_ID NUMBER NOT NULL,
  BU_CODE VARCHAR2(20) NOT NULL,
  BU_LOCATION VARCHAR2(80)
, CONSTRAINT BU_LOCATION_PK PRIMARY KEY
  (
    BU_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.COMPOSITIONTASK_APPEVENT
(
  APPEVENT_ID NUMBER NOT NULL,
  COMPOSITIONLIST_ID NUMBER NOT NULL
)
;

CREATE TABLE CTUSR.GU_LOCATION
(
  GU_ID NUMBER NOT NULL,
  GU_CODE VARCHAR2(20) NOT NULL,
  GU_LOCATION VARCHAR2(80) NOT NULL
, CONSTRAINT GU_LOCATION_PK PRIMARY KEY
  (
    GU_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.SERVICE_MODEL
(
  SERVICEMODEL_ID NUMBER NOT NULL,
  SERVICE_MODEL VARCHAR2(100) DEFAULT 'Task' NOT NULL,
  MODEL_DESCRIPTION VARCHAR2(2000)
, CONSTRAINT SERVICE_MODEL_PK PRIMARY KEY
  (
    SERVICEMODEL_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.COMPOSITIONTASK_RULES
(
  RULESET_ID NUMBER NOT NULL,
  COMPOSITIONLIST_ID NUMBER NOT NULL
)
;

CREATE TABLE CTUSR.OPERATION_TYPE
(
  OPERATIONTYPE_ID NUMBER NOT NULL,
  OPERATION VARCHAR2(80)
, CONSTRAINT TASK_TYPE_PK PRIMARY KEY
  (
    OPERATIONTYPE_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.COMPOSITION_ROLE
(
  ROLE_ID NUMBER NOT NULL,
  COMPOSITION_ROLE VARCHAR2(80) DEFAULT 'Composition Member' NOT NULL,
  ROLE_DESCRIPTION VARCHAR2(2000)
, CONSTRAINT COMPOSITION_ROLE_PK PRIMARY KEY
  (
    ROLE_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.APPLICATION_ENDPOINT
(
  APPENDPOINT_ID NUMBER NOT NULL,
  APPLICATION_ID NUMBER NOT NULL,
  ENDPOINT_ID NUMBER NOT NULL,
  MEP_ID NUMBER NOT NULL
, CONSTRAINT APPLICATION_ENDPOINT_PK PRIMARY KEY
  (
    APPENDPOINT_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.EVENT
(
  EVENT_ID NUMBER NOT NULL,
  EVENT_NAME VARCHAR2(80),
  EVENT_DESCRIPTION VARCHAR2(2000)
, CONSTRAINT EVENT_PK PRIMARY KEY
  (
    EVENT_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.RULE_AGGREGATION
(
  RULEAGGREGATION_ID NUMBER NOT NULL,
  RULE_AGGREGATION VARCHAR2(20)
, CONSTRAINT RULE_AGGREGATION_PK PRIMARY KEY
  (
    RULEAGGREGATION_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.ENDPOINT
(
  ENDPOINT_ID NUMBER NOT NULL,
  ENDPOINTYPE_ID NUMBER NOT NULL,
  PROTOCOL_ID NUMBER NOT NULL,
  ENDPOINT_URL VARCHAR2(200) NOT NULL,
  DESCRIPTION VARCHAR2(400)
, CONSTRAINT ENDPOINT_PK PRIMARY KEY
  (
    ENDPOINT_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.APPLICATION_EVENT
(
  APPEVENT_ID NUMBER NOT NULL,
  APPENDPOINT_ID NUMBER NOT NULL,
  EVENT_ID NUMBER NOT NULL
, CONSTRAINT APPLICATION_EVENT_PK PRIMARY KEY
  (
    APPEVENT_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.APPLICATION
(
  APPLICATION_ID NUMBER NOT NULL,
  APPLICATION_NAME VARCHAR2(60) NOT NULL,
  DESCRIPTION VARCHAR2(200),
  BU_ID NUMBER NOT NULL,
  GU_ID NUMBER NOT NULL,
  HANDBOOK_URL VARCHAR2(2000)
, CONSTRAINT APPLICATION_PK PRIMARY KEY
  (
    APPLICATION_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.PROCESS
(
  PROCESS_ID NUMBER NOT NULL,
  BU_ID NUMBER DEFAULT '1' NOT NULL,
  MEP_ID NUMBER NOT NULL,
  PROCESS_NAME VARCHAR2(100) DEFAULT 'n/a' NOT NULL,
  PROCESS_DESCRIPTION VARCHAR2(2000),
  LOGGING_LEVEL NUMBER DEFAULT 1 NOT NULL,
  SDD_URL VARCHAR2(20),
  PROC_CUSTODIAN VARCHAR2(80),
  SDD_CUSTODIAN VARCHAR2(80)
, CONSTRAINT PROCESS_PK PRIMARY KEY
  (
    PROCESS_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.POLICY
(
  POLICY_ID NUMBER NOT NULL,
  PROVIDER_ID NUMBER NOT NULL,
  POLICY_ELEMENT VARCHAR2(80) NOT NULL,
  ELEMENT_DESCRIPTION VARCHAR2(2000) DEFAULT 'n/a',
  DEFAULT_VALUE VARCHAR2(80) DEFAULT 'n/a'
, CONSTRAINT POLICY_PK PRIMARY KEY
  (
    POLICY_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.OBJECT
(
  OBJECT_ID NUMBER NOT NULL,
  OBJECT_NAME VARCHAR2(80) DEFAULT 'OBJECT' NOT NULL,
  UML_REF VARCHAR2(400)
, CONSTRAINT OBJECT_PK PRIMARY KEY
  (
    OBJECT_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.MEP
(
  MEP_ID NUMBER NOT NULL,
  MEP_NAME VARCHAR2(80) NOT NULL,
  MEP_DESCRIPTION VARCHAR2(2000)
, CONSTRAINT MEP_PK PRIMARY KEY
  (
    MEP_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.SERVICE_ENGINE
(
  ENGINE_ID NUMBER NOT NULL,
  ENGINE_TYPE VARCHAR2(80) DEFAULT 'JRE' NOT NULL,
  ENGINE_NAME VARCHAR2(80) DEFAULT 'EJB' NOT NULL,
  ENGINE_URL VARCHAR2(20)
, CONSTRAINT SERVICE_ENGINE_PK PRIMARY KEY
  (
    ENGINE_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.POLICY_PROVIDER
(
  PROVIDER_ID NUMBER NOT NULL,
  PROVIDER_URL VARCHAR2(400),
  POLICY_NAME VARCHAR2(80),
  PROVIDER_AUTHORITY VARCHAR2(80) DEFAULT 'CTU BR' NOT NULL
, CONSTRAINT POLICY_PROVIDER_PK PRIMARY KEY
  (
    PROVIDER_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.PROTOCOL
(
  PROTOCOL_ID NUMBER NOT NULL,
  PROTOCOL_NAME VARCHAR2(40) NOT NULL,
  PROTOCOL_VERSION VARCHAR2(20)
, CONSTRAINT PROTOCOL_PK PRIMARY KEY
  (
    PROTOCOL_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.SERVICE
(
  SERVICE_ID NUMBER NOT NULL,
  SERVICEMODEL_ID NUMBER DEFAULT '1' NOT NULL,
  TASK VARCHAR2(80) NOT NULL,
  ENGINE_ID NUMBER DEFAULT '1' NOT NULL,
  SERVICE_NAME VARCHAR2(200) DEFAULT 'task' NOT NULL,
  SERVICE_DESCRIPTION VARCHAR2(2000),
  SERVICE_URL VARCHAR2(400),
  SERVICE_HOST VARCHAR2(400)
, CONSTRAINT SERVICE_PK PRIMARY KEY
  (
    SERVICE_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.COMPOSITION
(
  COMPOSITIONLIST_ID NUMBER NOT NULL,
  PROCESS_ID NUMBER NOT NULL,
  SERVICE_ID NUMBER NOT NULL,
  TASK_ORDER NUMBER NOT NULL,
  OPERATIONTYPE_ID NUMBER NOT NULL,
  ROLE_ID NUMBER NOT NULL
, CONSTRAINT COMPOSITION_PK PRIMARY KEY
  (
    COMPOSITIONLIST_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.PROCESS_PATTERNS
(
  PATTERN_ID NUMBER NOT NULL,
  IMPLEMENTATION_NOTE VARCHAR2(2000),
  PROCESS_ID NUMBER NOT NULL
)
;

CREATE TABLE CTUSR.RULE
(
  RULE_ID NUMBER NOT NULL,
  SERVICE_ID NUMBER NOT NULL,
  RULESET_ID NUMBER NOT NULL,
  RULE_TYPE VARCHAR2(20),
  RULE_NAME VARCHAR2(80),
  RULE_DATA  VARCHAR2(2000) NOT NULL,
  RULE_EXP   VARCHAR2(2000), 
  RULE_SEQUENCE NUMBER DEFAULT 1 NOT NULL,
  RULEAGGREGATION_ID NUMBER NOT NULL,
  RULEVERIFICATION_ID NUMBER NOT NULL,
  RULE_DESCRIPTION VARCHAR2(2000),
  POLICY_ID NUMBER,
  ACTIVE VARCHAR2(2) DEFAULT 'Y'
, CONSTRAINT RULE_PK PRIMARY KEY
  (
    RULE_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.RULESET
(
  RULESET_ID NUMBER NOT NULL,
  RULESET_NAME VARCHAR2(80),
  RULESET_DESCRIPTION VARCHAR2(2000)
, CONSTRAINT RULESET_PK PRIMARY KEY
  (
    RULESET_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.COMPOSITIONTASK_MESSAGE
(
  TASKMSG_ID NUMBER NOT NULL,
  COMPOSITIONLIST_ID NUMBER NOT NULL,
  TRANSFORMATION_TASK VARCHAR2(1),
  VALIDATION_TASK VARCHAR2(1),
  SOURCE NUMBER,
  TARGET NUMBER,
  XSLT_URL VARCHAR2(400),
  MESSAGE_ID NUMBER NOT NULL
, CONSTRAINT COMPOSITIONTASK_MESSAGE_PK PRIMARY KEY
  (
    TASKMSG_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.MESSAGE
(
  MESSAGE_ID NUMBER NOT NULL,
  OBJECT_ID NUMBER DEFAULT '1' NOT NULL,
  MESSAGE_NAME VARCHAR2(80) DEFAULT 'Message' NOT NULL,
  MESSAGE_FILENAME VARCHAR2(80) DEFAULT 'CTUMessage' NOT NULL,
  MESSAGE_FILETYPE VARCHAR2(4) DEFAULT 'xml' NOT NULL,
  MESSAGE_DESCRIPTION VARCHAR2(2000) DEFAULT 'Message' NOT NULL,
  MESSAGE_ROOT VARCHAR2(20) DEFAULT 'message' NOT NULL,
  VERSION VARCHAR2(20) DEFAULT '1.0' NOT NULL,
  XSD_URL VARCHAR2(400),
  MESSAGE_NAMESPACE VARCHAR2(400),
  IMPLEMENTATION VARCHAR2(40) DEFAULT 'XSD' NOT NULL,
  HEADER_VERSION VARCHAR2(20) DEFAULT '0' NOT NULL
, CONSTRAINT MESSAGE_PK PRIMARY KEY
  (
    MESSAGE_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.RULE_VERIFICATION
(
  RULEVERIFICATION_ID NUMBER NOT NULL,
  RULE_VERIFICATION VARCHAR2(20)
, CONSTRAINT RULE_VERIFICATION_PK PRIMARY KEY
  (
    RULEVERIFICATION_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.PATTERN
(
  PATTERN_ID NUMBER NOT NULL,
  PATTERN_NAME VARCHAR2(80),
  PATTERN_DESCRIPTION VARCHAR2(2000),
  PATTERN_URL VARCHAR2(2000)
, CONSTRAINT PATTERN_PK PRIMARY KEY
  (
    PATTERN_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.PROCESS_POLICY
(
  PROCESSPOLICY_ID NUMBER NOT NULL,
  POLICY_ID NUMBER NOT NULL,
  PROCESS_ID NUMBER NOT NULL,
  PROCESSPOLICY_VALUE VARCHAR2(20) DEFAULT 'NA' NOT NULL
, CONSTRAINT PROCESS_POLICY_PK PRIMARY KEY
  (
    PROCESSPOLICY_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.OBJECT_PARAMETER
(
  OBJECTPARAMETER_ID NUMBER NOT NULL,
  OBJECT_ID NUMBER NOT NULL,
  PARAMETER_ID NUMBER,
  OBJPRIMARY_KEY VARCHAR2(1),
  PARAMETER_ORDER NUMBER DEFAULT 1,
  CONSTRAINT OBJECT_PARAMETER_PK PRIMARY KEY
  (
    OBJECTPARAMETER_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.EVENT_MESSAGETYPE
(
  EVENTMESSAGETYPE_ID NUMBER NOT NULL,
  EVENTMESSAGETYPE_NAME VARCHAR2(80),
  CONSTRAINT  EVENTMESSAGETYPE_PK PRIMARY KEY
  (
    EVENTMESSAGETYPE_ID
  )
  ENABLE
)
;


CREATE TABLE CTUSR.EVENT_MESSAGE
(
  EVENTMESSAGE_ID NUMBER NOT NULL,
  EVENTMESSAGE_CODE VARCHAR2(400) DEFAULT 'NA' NOT NULL,
  EVENTMESSAGE_NAME VARCHAR2(4000),
  EVENTMESSAGE_DESCRIPTION VARCHAR2(4000),
  EVENTMESSAGETYPE_ID NUMBER,
  CONSTRAINT EVENTMESSAGE_PK PRIMARY KEY
  (
    EVENTMESSAGE_ID
  )
  ENABLE
)
;

CREATE TABLE CTUSR.EVENTMESSAGE_SERVICE
  (
    EVENTMESSAGE_ID                NUMBER NOT NULL, -- < Message/Error Code
    COMPOSITIONLIST_ID             NUMBER NOT NULL, -- < Combination of Service/Process/Operation
    RESOLUTION_OPERATIONTYPE_ID    NUMBER NOT NULL, -- < Resolution Action, based on first two parameters and retry count
    RESOLUTION_PROCESS_ID          NUMBER,          -- < Resolution Process, based on first two parameters and retry count
    RETRY_COUNT                    NUMBER NOT NULL, -- < Retry count, number of operations, performed by service. Condition for resolution action. Provided by ErrMan
    RETRY_INTERVAL                 NUMBER NOT NULL  -- < Retry interval. Output parameter
  )
;
  
COMMENT ON COLUMN CTUSR.EVENTMESSAGE_SERVICE.RESOLUTION_OPERATIONTYPE_ID
IS 'Resolution Action';

COMMENT ON COLUMN CTUSR.EVENTMESSAGE_SERVICE.RESOLUTION_PROCESS_ID
IS 'Resolution Process';




CREATE TABLE "CTUSR"."RESOLUTION_PROCESS"
  (
    "EVENTMESSAGE_ID"             NUMBER NOT NULL ENABLE,
    "COMPOSITIONLIST_ID"          NUMBER NOT NULL ENABLE,
    "RESOLUTION_OPS_ID"           NUMBER NOT NULL ENABLE,
    "RESOLUTION_PROCESS_ID"       NUMBER,
    "RETRY_COUNT"                 NUMBER NOT NULL ENABLE,
    "RETRY_INTERVAL"        NUMBER NOT NULL ENABLE,
    "PROCESS_ID"            NUMBER,
    "PROCESS_NAME"          VARCHAR2(200 BYTE),
    "TASK"                  VARCHAR2(200 BYTE),
    "TASK_ORDER"            NUMBER,
    CONSTRAINT "EH_SERVICE_UNIQ" UNIQUE ("EVENTMESSAGE_ID", "COMPOSITIONLIST_ID", "RETRY_COUNT") USING INDEX PCTFREE 10 INITRANS 2 MAXTRANS 255 COMPUTE STATISTICS STORAGE(INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT) TABLESPACE "CTU_DATA" ENABLE,
    CONSTRAINT "EH_SERVICE_MESSAGE_FK" FOREIGN KEY ("EVENTMESSAGE_ID") REFERENCES "CTUSR"."EVENT_MESSAGE" ("EVENTMESSAGE_ID") ENABLE,
    CONSTRAINT "EH_SERVICE_PROCESS_FK" FOREIGN KEY ("RESOLUTION_PROCESS_ID") REFERENCES "CTUSR"."PROCESS" ("PROCESS_ID") ENABLE,
    CONSTRAINT "EH_SERVICE_PROCOPER_FK" FOREIGN KEY ("RESOLUTION_OPS_ID") REFERENCES "CTUSR"."OPERATION_TYPE" ("OPERATIONTYPE_ID") ENABLE
  )
  SEGMENT CREATION IMMEDIATE PCTFREE 10 PCTUSED 40 INITRANS 1 MAXTRANS 255 NOCOMPRESS LOGGING STORAGE
  (
    INITIAL 65536 NEXT 1048576 MINEXTENTS 1 MAXEXTENTS 2147483645 PCTINCREASE 0 FREELISTS 1 FREELIST GROUPS 1 BUFFER_POOL DEFAULT FLASH_CACHE DEFAULT CELL_FLASH_CACHE DEFAULT
  )
  TABLESPACE "CTU_DATA" ;

COMMENT ON COLUMN "CTUSR"."RESOLUTION_PROCESS"."RESOLUTION_OPS_ID"
IS  'Resolution Action';

COMMENT ON COLUMN "CTUSR"."RESOLUTION_PROCESS"."RESOLUTION_PROCESS_ID"
IS  'Resolution Process';

---- CONSTRAINTS-----------------------------------------------------------------------------


ALTER TABLE CTUSR.BU_LOCATION
ADD CONSTRAINT BU_LOCATION_UK UNIQUE
(
  BU_LOCATION
)
 ENABLE
;

ALTER TABLE CTUSR.COMPOSITIONTASK_MESSAGE
ADD CONSTRAINT COMPOSITIONTASK_MESSAGE_UK UNIQUE
(
  SOURCE
)
 ENABLE
;


ALTER TABLE CTUSR.EVENT_MESSAGE
ADD CONSTRAINT EVENTMESSAGETYPE_ID_FK FOREIGN KEY
(
  EVENTMESSAGETYPE_ID
)
REFERENCES CTUSR.EVENT_MESSAGETYPE
(
  EVENTMESSAGETYPE_ID
)
 ENABLE
;



ALTER TABLE CTUSR.COMPOSITIONTASK_APPEVENT
ADD CONSTRAINT APPEVENT_COMPOSITION_FK1 FOREIGN KEY
(
  COMPOSITIONLIST_ID
)
REFERENCES CTUSR.COMPOSITION
(
  COMPOSITIONLIST_ID
)
 ENABLE
;

ALTER TABLE CTUSR.COMPOSITIONTASK_APPEVENT
ADD CONSTRAINT COMPOSITIONTASK_APPEVENT_FK FOREIGN KEY
(
  APPEVENT_ID
)
REFERENCES CTUSR.APPLICATION_EVENT
(
  APPEVENT_ID
)
 ENABLE
;

ALTER TABLE CTUSR.COMPOSITIONTASK_RULES
ADD CONSTRAINT COMPOSITIONTASK_RULES_FK FOREIGN KEY
(
  RULESET_ID
)
REFERENCES CTUSR.RULESET
(
  RULESET_ID
)
 ENABLE
;

ALTER TABLE CTUSR.COMPOSITIONTASK_RULES
ADD CONSTRAINT COMPOSITIONTASK_RULES_FK1 FOREIGN KEY
(
  COMPOSITIONLIST_ID
)
REFERENCES CTUSR.COMPOSITION
(
  COMPOSITIONLIST_ID
)
 ENABLE
;


ALTER TABLE CTUSR.EVENTMESSAGE_SERVICE
ADD CONSTRAINT EVENTMESSAGE_MESSAGE_FK FOREIGN KEY
(
  EVENTMESSAGE_ID
)
REFERENCES CTUSR.EVENT_MESSAGE
(
  EVENTMESSAGE_ID
)
 ENABLE
;

ALTER TABLE CTUSR.EVENTMESSAGE_SERVICE
ADD CONSTRAINT EVENTMESSAGE_PROCESS_FK FOREIGN KEY
(
  RESOLUTION_PROCESS_ID
)
REFERENCES CTUSR.PROCESS
(
  PROCESS_ID
)
 ENABLE
;


ALTER TABLE CTUSR.EVENTMESSAGE_SERVICE
ADD CONSTRAINT EVENTMESSAGE_PROCOPER_FK FOREIGN KEY
(
  RESOLUTION_OPERATIONTYPE_ID
)
REFERENCES CTUSR.OPERATION_TYPE
(
  OPERATIONTYPE_ID
)
 ENABLE
;


ALTER TABLE CTUSR.EVENTMESSAGE_SERVICE
ADD CONSTRAINT "EVENTMESSAGE_SERVICE_UNIQ" UNIQUE
("EVENTMESSAGE_ID", "COMPOSITIONLIST_ID", "RETRY_COUNT")
;

ALTER TABLE CTUSR.APPLICATION_ENDPOINT
ADD CONSTRAINT APPLICATION_ENDPOINT_FK FOREIGN KEY
(
  APPLICATION_ID
)
REFERENCES CTUSR.APPLICATION
(
  APPLICATION_ID
)
 ENABLE
;

ALTER TABLE CTUSR.APPLICATION_ENDPOINT
ADD CONSTRAINT APPLICATION_ENDPOINT_FK1 FOREIGN KEY
(
  ENDPOINT_ID
)
REFERENCES CTUSR.ENDPOINT
(
  ENDPOINT_ID
)
 ENABLE
;

ALTER TABLE CTUSR.APPLICATION_ENDPOINT
ADD CONSTRAINT APPLICATION_ENDPOINT_MEP_FK FOREIGN KEY
(
  MEP_ID
)
REFERENCES CTUSR.MEP
(
  MEP_ID
)
 ENABLE
;

ALTER TABLE CTUSR.ENDPOINT
ADD CONSTRAINT ENDPOINT_ENDPOINTTYPE_FK FOREIGN KEY
(
  ENDPOINTYPE_ID
)
REFERENCES CTUSR.ENDPOINT_TYPE
(
  ENDPOINTYPE_ID
)
 ENABLE
;

ALTER TABLE CTUSR.ENDPOINT
ADD CONSTRAINT ENDPOINT_PROTOCOL_FK FOREIGN KEY
(
  PROTOCOL_ID
)
REFERENCES CTUSR.PROTOCOL
(
  PROTOCOL_ID
)
 ENABLE
;

ALTER TABLE CTUSR.APPLICATION_EVENT
ADD CONSTRAINT APPLICATION_EVENT_EVENT_FK FOREIGN KEY
(
  EVENT_ID
)
REFERENCES CTUSR.EVENT
(
  EVENT_ID
)
 ENABLE
;

ALTER TABLE CTUSR.APPLICATION_EVENT
ADD CONSTRAINT APPLICATION_EVENT_FK FOREIGN KEY
(
  APPENDPOINT_ID
)
REFERENCES CTUSR.APPLICATION_ENDPOINT
(
  APPENDPOINT_ID
)
 ENABLE
;

ALTER TABLE CTUSR.APPLICATION
ADD CONSTRAINT APPLICATION_BU_LOCATION_FK FOREIGN KEY
(
  BU_ID
)
REFERENCES CTUSR.BU_LOCATION
(
  BU_ID
)
 ENABLE
;

ALTER TABLE CTUSR.APPLICATION
ADD CONSTRAINT APPLICATION_GU_LOCATION_FK FOREIGN KEY
(
  GU_ID
)
REFERENCES CTUSR.GU_LOCATION
(
  GU_ID
)
 ENABLE
;

ALTER TABLE CTUSR.PROCESS
ADD CONSTRAINT PROCESS_BU_LOCATION_FK FOREIGN KEY
(
  BU_ID
)
REFERENCES CTUSR.BU_LOCATION
(
  BU_ID
)
 ENABLE
;

ALTER TABLE CTUSR.PROCESS
ADD CONSTRAINT PROCESS_MEP_FK FOREIGN KEY
(
  MEP_ID
)
REFERENCES CTUSR.MEP
(
  MEP_ID
)
 ENABLE
;

ALTER TABLE CTUSR.POLICY
ADD CONSTRAINT POLICY_POLICY_PROVIDER_FK FOREIGN KEY
(
  PROVIDER_ID
)
REFERENCES CTUSR.POLICY_PROVIDER
(
  PROVIDER_ID
)
 ENABLE
;

ALTER TABLE CTUSR.SERVICE
ADD CONSTRAINT SERVICE_SERVICE_ENGINE_FK FOREIGN KEY
(
  ENGINE_ID
)
REFERENCES CTUSR.SERVICE_ENGINE
(
  ENGINE_ID
)
 ENABLE
;

ALTER TABLE CTUSR.SERVICE
ADD CONSTRAINT SERVICE_SERVICE_MODEL_FK FOREIGN KEY
(
  SERVICEMODEL_ID
)
REFERENCES CTUSR.SERVICE_MODEL
(
  SERVICEMODEL_ID
)
 ENABLE
;

ALTER TABLE CTUSR.COMPOSITION
ADD CONSTRAINT COMPOSITION_FK FOREIGN KEY
(
  ROLE_ID
)
REFERENCES CTUSR.COMPOSITION_ROLE
(
  ROLE_ID
)
 ENABLE
;

ALTER TABLE CTUSR.COMPOSITION
ADD CONSTRAINT COMPOSITION_OPERATION_TYPE_FK FOREIGN KEY
(
  OPERATIONTYPE_ID
)
REFERENCES CTUSR.OPERATION_TYPE
(
  OPERATIONTYPE_ID
)
 ENABLE
;

ALTER TABLE CTUSR.COMPOSITION
ADD CONSTRAINT COMPOSITION_PROCESS_FK FOREIGN KEY
(
  PROCESS_ID
)
REFERENCES CTUSR.PROCESS
(
  PROCESS_ID
)
 ENABLE
;

ALTER TABLE CTUSR.COMPOSITION
ADD CONSTRAINT COMPOSITION_SERVICE_FK FOREIGN KEY
(
  SERVICE_ID
)
REFERENCES CTUSR.SERVICE
(
  SERVICE_ID
)
 ENABLE
;

ALTER TABLE CTUSR.PROCESS_PATTERNS
ADD CONSTRAINT PROCESS_PATTERNS_PATTERN_FK FOREIGN KEY
(
  PATTERN_ID
)
REFERENCES CTUSR.PATTERN
(
  PATTERN_ID
)
 ENABLE
;

ALTER TABLE CTUSR.PROCESS_PATTERNS
ADD CONSTRAINT PROCESS_PATTERNS_PROCESS_FK FOREIGN KEY
(
  PROCESS_ID
)
REFERENCES CTUSR.PROCESS
(
  PROCESS_ID
)
 ENABLE
;

ALTER TABLE CTUSR.RULE
ADD CONSTRAINT RULE_RULESET_FK FOREIGN KEY
(
  RULESET_ID
)
REFERENCES CTUSR.RULESET
(
  RULESET_ID
)
 ENABLE
;

ALTER TABLE CTUSR.RULE
ADD CONSTRAINT RULE_RULE_AGGREGATION_FK FOREIGN KEY
(
  RULEAGGREGATION_ID
)
REFERENCES CTUSR.RULE_AGGREGATION
(
  RULEAGGREGATION_ID
)
 ENABLE
;

ALTER TABLE CTUSR.RULE
ADD CONSTRAINT RULE_RULE_VERIFICATION_FK FOREIGN KEY
(
  RULEVERIFICATION_ID
)
REFERENCES CTUSR.RULE_VERIFICATION
(
  RULEVERIFICATION_ID
)
 ENABLE
;

ALTER TABLE CTUSR.RULE
ADD CONSTRAINT RULE_SERVICE_FK FOREIGN KEY
(
  SERVICE_ID
)
REFERENCES CTUSR.SERVICE
(
  SERVICE_ID
)
 ENABLE
;

ALTER TABLE CTUSR.RULE
ADD CONSTRAINT RULE_POLICY_FK FOREIGN KEY
(
  POLICY_ID
)
REFERENCES CTUSR.POLICY
(
  POLICY_ID
)
 ENABLE
;

ALTER TABLE CTUSR.COMPOSITIONTASK_MESSAGE
ADD CONSTRAINT COMPOSITIONTASK_MESSAGE_FK FOREIGN KEY
(
  COMPOSITIONLIST_ID
)
REFERENCES CTUSR.COMPOSITION
(
  COMPOSITIONLIST_ID
)
 ENABLE
;

ALTER TABLE CTUSR.COMPOSITIONTASK_MESSAGE
ADD CONSTRAINT COMPOSITIONTASK_MESSAGE_FK1 FOREIGN KEY
(
  MESSAGE_ID
)
REFERENCES CTUSR.MESSAGE
(
  MESSAGE_ID
)
 ENABLE
;

ALTER TABLE CTUSR.MESSAGE
ADD CONSTRAINT MESSAGE_OBJECT_FK FOREIGN KEY
(
  OBJECT_ID
)
REFERENCES CTUSR.OBJECT
(
  OBJECT_ID
)
 ENABLE
;

ALTER TABLE CTUSR.PROCESS_POLICY
ADD CONSTRAINT PROCESS_POLICY_POLICY_FK FOREIGN KEY
(
  POLICY_ID
)
REFERENCES CTUSR.POLICY
(
  POLICY_ID
)
 ENABLE
;

ALTER TABLE CTUSR.PROCESS_POLICY
ADD CONSTRAINT PROCESS_POLICY_PROCESS_FK FOREIGN KEY
(
  PROCESS_ID
)
REFERENCES CTUSR.PROCESS
(
  PROCESS_ID
)
 ENABLE
;


ALTER TABLE CTUSR.OBJECT_PARAMETER
ADD CONSTRAINT OBJECT_PARAMETER_OBJECT_FK FOREIGN KEY
(
  OBJECT_ID
)
REFERENCES CTUSR.OBJECT
(
  OBJECT_ID
)
 ENABLE
;

ALTER TABLE CTUSR.OBJECT_PARAMETER
ADD CONSTRAINT OBJECT_PARAMETER_PARAMETER_FK FOREIGN KEY
(
  PARAMETER_ID
)
REFERENCES CTUSR.PARAMETER
(
  PARAMETER_ID
)
 ENABLE
;

ALTER TABLE CTUSR.RESOLUTION_PROCESS
ADD 
	 CONSTRAINT RESOLUTION_PROCESS_PROCESS_FK FOREIGN KEY 
(
   PROCESS_ID
)
REFERENCES CTUSR.PROCESS
(
   PROCESS_ID
)
 ENABLE
;

----------------- COMMENTs---------------------------------------------------------------
COMMENT ON TABLE CTUSR.ENDPOINT_TYPE IS 'Physical type of endpoint implementation: AQ, MQ, FSO (Folder), WS, HTTP Servlet.'
;

COMMENT ON TABLE CTUSR.BU_LOCATION IS 'Business Unit Location'
;

COMMENT ON TABLE CTUSR.GU_LOCATION IS 'Geographical Unit Location'
;

COMMENT ON TABLE CTUSR.SERVICE_MODEL IS 'Service Model implementation: Utility, Entity, Task, Orchestration Task,  Hybrid, Utility Legacy Wrapper'
;

COMMENT ON TABLE CTUSR.OPERATION_TYPE IS 'Operation type for Message Broker specific  operations (RTD, receive-transform-deliver) OR as described for WS-BPEL spec in http://www.oasis-open.org/committees/download.php/14616/wsbpel-specification-draft.htm. Basic operations between Start and Stop are : Receive, Send, Invoke, Assign, Transform, Validate. Used for task operation description in Composition '
;

COMMENT ON TABLE CTUSR.COMPOSITION_ROLE IS 'Role which service plays in composition. Dictionary according common SOA standards.'
;

COMMENT ON TABLE CTUSR.EVENT IS 'Entity object table, containing all recognized EVENTS, registered for whole Enterprise. Events are application specific and object related. This table primarily store message0related business events. Can be used for TP recognition, dynamic routing and decision services.'
;

COMMENT ON TABLE CTUSR.ENDPOINT IS 'Physical Endpoint Description'
;

COMMENT ON TABLE CTUSR.APPLICATION IS 'Registry for all enterprise applications, participated in integration processes. ID and names are unique and descriptive. Its a list of senders, consumers or data providers. Standalone service engines also shall be included. Role of application defined via composition.'
;

COMMENT ON TABLE CTUSR.PROCESS IS 'Design time definition table with elements for runtime recognition. Describes individual business process for predefined physical composition of services. Mater table for linking many-to-many relations tables for EVENT, MESSAGE, ENDPOINT, RULESET. Directly linked to SDD.'
;

COMMENT ON TABLE CTUSR.POLICY IS 'Atomic policy element in use. Can be custom or from officially provided, with relation to policy file. TechnicalTimeout, BusinessTimeout, Nack, DeliverOnlyOnce,  etc'
;

COMMENT ON TABLE CTUSR.OBJECT IS 'Description of object. Enterprise(canonical) or Application'
;

COMMENT ON TABLE CTUSR.MEP IS 'Message Interchange Pattern according to WSDL 2.0: in-out, out-in, out-only, robust in-only , robust out-only, in-optional-out, out-optional-in '
;

COMMENT ON TABLE CTUSR.SERVICE_ENGINE IS 'Physical implementation of Service Engine for running concrete task or service: DB or JAVA with reference to engine implementation like  jakarta.commons.httpclient.strict or EJB container class. Used for dispatching task/service to the engine for IOC or NDS'
;

COMMENT ON TABLE CTUSR.POLICY_PROVIDER IS 'Policy provider for selected policy: Local bank provider as Default. Possible providers are : OASIS, W3C, WS-I '
;

COMMENT ON TABLE CTUSR.PROTOCOL IS 'Protocol associated with endpoint with version: SOAP 1.1, SOAP 1.2, HTTP(S), FSO, JMS/MQ, FTP.'
;

COMMENT ON TABLE CTUSR.SERVICE IS 'Service as an executable atomic unit of work. Can be single task of composite application defined as an orchestrated task. Could be WS, EJB, PL\SQL function, etc.'
;

COMMENT ON TABLE CTUSR.COMPOSITION IS 'Service composition as a logical collection of individual services. Runtime table with link to the main runtime parameters, top level of individual ESB/MB service composition'
;

COMMENT ON TABLE CTUSR.MESSAGE IS 'Description of object transport, presented as XSD or by other means.'
;

COMMENT ON TABLE CTUSR.PATTERN IS 'SOA or any other standard pattern. Repository for Design Time with links to reference model '
;

COMMENT ON COLUMN CTUSR.ENDPOINT_TYPE.ENDPOINTYPE_ID IS 'Primary key. Internal. Numerical'
;

COMMENT ON COLUMN CTUSR.ENDPOINT_TYPE.ENDPOINTTYPE_NAME IS 'Endpoint Type according spec'
;

COMMENT ON COLUMN CTUSR.ENDPOINT_TYPE.ENDPOINT_DESCRIPTION IS 'Description with current implementation specification'
;

COMMENT ON COLUMN CTUSR.BU_LOCATION.BU_ID IS 'Primary key. Internal. Numerical'
;

COMMENT ON COLUMN CTUSR.BU_LOCATION.BU_CODE IS 'BU Code, like BOAA'
;

COMMENT ON COLUMN CTUSR.BU_LOCATION.BU_LOCATION IS 'Business Unit Location description. Short, descriptive'
;

COMMENT ON COLUMN CTUSR.GU_LOCATION.GU_ID IS 'Primary key. Internal. Numerical'
;

COMMENT ON COLUMN CTUSR.GU_LOCATION.GU_CODE IS 'GU Code, like LT, LV, DK'
;

COMMENT ON COLUMN CTUSR.GU_LOCATION.GU_LOCATION IS 'Geographical Unit Location description. Short, descriptive'
;

COMMENT ON COLUMN CTUSR.SERVICE_MODEL.SERVICEMODEL_ID IS 'Primary key. Internal. Numerical'
;

COMMENT ON COLUMN CTUSR.SERVICE_MODEL.SERVICE_MODEL IS 'Service Model implementation: Utility, Entity, Task, Orchestration Task,  Hybrid, Utility Legacy Wrapper. Design Time information'
;

COMMENT ON COLUMN CTUSR.COMPOSITION_ROLE.ROLE_ID IS 'Primary key. Internal. Numerical'
;

COMMENT ON COLUMN CTUSR.COMPOSITION_ROLE.COMPOSITION_ROLE IS 'Definition of the role service plays in composition, like Designated Controller, Composition Initiator etc '
;

COMMENT ON COLUMN CTUSR.COMPOSITION_ROLE.ROLE_DESCRIPTION IS 'Detailed description of composition role.'
;

COMMENT ON COLUMN CTUSR.EVENT.EVENT_ID IS 'Primary key for business EVENT'
;

COMMENT ON COLUMN CTUSR.EVENT.EVENT_NAME IS 'Business name of event according corporate standard. '
;

COMMENT ON COLUMN CTUSR.EVENT.EVENT_DESCRIPTION IS 'Event description as conditions, prerequisites, business case. Important field for FA concern.  '
;

COMMENT ON COLUMN CTUSR.ENDPOINT.ENDPOINT_ID IS 'Primary key. Internal. Numerical'
;

COMMENT ON COLUMN CTUSR.ENDPOINT.ENDPOINT_URL IS 'Endpoints URL, as WS, HTTP address , FSO location, MQ/AQ location '
;

COMMENT ON COLUMN CTUSR.ENDPOINT.DESCRIPTION IS 'Endpoint s description. Short, descriptive'
;

COMMENT ON COLUMN CTUSR.APPLICATION.APPLICATION_ID IS 'Primary key. Internal. Numerical'
;

COMMENT ON COLUMN CTUSR.APPLICATION.APPLICATION_NAME IS 'Application name. Short, descriptive'
;

COMMENT ON COLUMN CTUSR.APPLICATION.DESCRIPTION IS 'Description note'
;

COMMENT ON COLUMN CTUSR.APPLICATION.HANDBOOK_URL IS 'Location of handbook with endpoints and interface descriptions, event and object used'
;

COMMENT ON COLUMN CTUSR.PROCESS.PROCESS_ID IS 'Primary key. Internal. Numerical'
;

COMMENT ON COLUMN CTUSR.PROCESS.BU_ID IS 'Business unit ID'
;

COMMENT ON COLUMN CTUSR.PROCESS.PROCESS_NAME IS 'Descriptive process name according SDD'
;

COMMENT ON COLUMN CTUSR.PROCESS.PROCESS_DESCRIPTION IS 'Detailed description'
;

COMMENT ON COLUMN CTUSR.PROCESS.LOGGING_LEVEL IS 'Logging level as a code for MB. Runtime value'
;

COMMENT ON COLUMN CTUSR.PROCESS.SDD_URL IS 'Link to SDD'
;

COMMENT ON COLUMN CTUSR.PROCESS.PROC_CUSTODIAN IS 'Process owner'
;

COMMENT ON COLUMN CTUSR.PROCESS.SDD_CUSTODIAN IS 'SDD owner'
;

COMMENT ON COLUMN CTUSR.POLICY.POLICY_ELEMENT IS 'XPath to xml policy element in Policy XML file'
;

COMMENT ON COLUMN CTUSR.OBJECT.OBJECT_ID IS 'Primary key. Internal. Numerical'
;

COMMENT ON COLUMN CTUSR.OBJECT.OBJECT_NAME IS 'Object name, application or enterprise'
;

COMMENT ON COLUMN CTUSR.OBJECT.UML_REF IS 'Link to UML'
;

COMMENT ON COLUMN CTUSR.PROTOCOL.PROTOCOL_ID IS 'Primary key. Internal. Numerical'
;

COMMENT ON COLUMN CTUSR.PROTOCOL.PROTOCOL_NAME IS 'Protocol name according protocols spec'
;

COMMENT ON COLUMN CTUSR.PROTOCOL.PROTOCOL_VERSION IS 'Protocol version'
;

COMMENT ON COLUMN CTUSR.SERVICE.SERVICE_ID IS 'Primary key. Internal. Numerical'
;

COMMENT ON COLUMN CTUSR.SERVICE.TASK IS 'Executable atomic unit of work. Executable, Not an textual description'
;

COMMENT ON COLUMN CTUSR.SERVICE.ENGINE_ID IS 'Reference to the service engine'
;

COMMENT ON COLUMN CTUSR.SERVICE.SERVICE_NAME IS 'Short service name'
;

COMMENT ON COLUMN CTUSR.SERVICE.SERVICE_DESCRIPTION IS 'Detailed description'
;

COMMENT ON COLUMN CTUSR.SERVICE.SERVICE_URL IS 'Access point or container'
;

COMMENT ON COLUMN CTUSR.SERVICE.SERVICE_HOST IS 'Deployment location'
;

COMMENT ON COLUMN CTUSR.COMPOSITION.ROLE_ID IS 'Primary key. Internal. Numerical'
;

COMMENT ON COLUMN CTUSR.COMPOSITIONTASK_MESSAGE.MESSAGE_ID IS 'Primary key. Internal. Numerical'
;

COMMENT ON COLUMN CTUSR.MESSAGE.MESSAGE_ID IS 'Primary key. Internal. Numerical'
;

COMMENT ON COLUMN CTUSR.MESSAGE.OBJECT_ID IS 'Reference to the Object , application or enterprise'
;

COMMENT ON COLUMN CTUSR.MESSAGE.MESSAGE_NAME IS 'Description of the message.'
;

COMMENT ON COLUMN CTUSR.MESSAGE.MESSAGE_ROOT IS 'Root element, used for message identification and namespace alteration'
;

COMMENT ON COLUMN CTUSR.MESSAGE.VERSION IS 'Current version as N.NN'
;

COMMENT ON COLUMN CTUSR.MESSAGE.XSD_URL IS 'Link to the XSD or other message definition format'
;

COMMENT ON COLUMN CTUSR.MESSAGE.MESSAGE_NAMESPACE IS 'Default namespace'
;

COMMENT ON COLUMN CTUSR.MESSAGE.IMPLEMENTATION IS 'Vendors specific implementation as XSD, DTD, MessageSet'
;

COMMENT ON COLUMN CTUSR.MESSAGE.HEADER_VERSION IS 'Version of message header in use. No MH if set to 0. Message Header also must be declared as message'
;

